@@ -6,14 +6,15 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.7'
-__release__ = 20230117
+__version__ = '0.5.12'
+__release__ = 20230124
 __all__ = ['Unit', 'is_Unit']
 
-from unyts.errors import WrongUnitsError, WrongValueError, NoConversionFoundError
-from unyts.operations import unit_product as _unit_product, unit_division as _unit_division, unit_base_power as _unit_base_power
-from unyts.helpers.unit_string_tools import reduce_units as _reduce_units
-from unyts.converter import convert as _convert, convertible as _convertible
+from .errors import WrongUnitsError, WrongValueError, NoConversionFoundError
+from .operations import unit_product as _unit_product, unit_division as _unit_division, \
+    unit_base_power as _unit_base_power
+from .helpers.unit_string_tools import reduce_units as _reduce_units
+from .converter import convert as _convert, convertible as _convertible
 from numbers import Number
 
 
@@ -47,7 +48,12 @@ else:
     array_like = tuple()
 
 
-class Unit(object):
+class UnytType(type):
+    def __repr__(self):
+        return self.__name__
+
+
+class Unit(object, metaclass=UnytType):
     """
     A class to cope with values associated to units, its arithmetic and logic
     operations and conversions.
@@ -89,12 +95,13 @@ class Unit(object):
         else:
             raise NotImplementedError("dtype not implemented without NumPy.")
 
-    def convert(self, new_unit):
-        if type(new_unit) is not str:
-            try:
-                new_unit = new_unit.unit
-            except AttributeError:
-                raise WrongUnitsError("'" + str(new_unit) + "' for '" + str(self.name) + "'")
+    def convert(self, new_unit: str):
+        if type(new_unit) is not str and hasattr(new_unit, 'units') and type(new_unit.units) is str:
+            new_unit = new_unit.units
+        elif type(new_unit) is not str:
+            raise TypeError("`new_units` should be string.")
+        if not _convertible(self.unit, new_unit):
+            raise WrongUnitsError("'" + str(new_unit) + "' is not valid units for '" + str(self.name) + "'.")
         return self.kind(_convert(self.value, self.unit, new_unit), new_unit)
 
     def to(self, new_unit):
@@ -115,7 +122,7 @@ class Unit(object):
 
     def __add__(self, other):
         from .units.unitless import Dimensionless, Percentage
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if other.kind is self.kind:
                 if self.unit == other.unit:
                     return self.kind(self.value + other.value, self.unit)
@@ -149,7 +156,7 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__radd__(self)
         else:
-            raise NotImplementedError("Addition of Unit and " + str(type(other)) + " not implemented.")
+            raise NotImplementedError("Addition of " + str(type(self)) + " and " + str(type(other)) + " not implemented.")
 
     def __radd__(self, other):
         return self.__add__(other)
@@ -157,7 +164,7 @@ class Unit(object):
     def __mul__(self, other):
         from .units.unitless import Dimensionless, Percentage
         from .units.define import units
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value * other.value, other.unit)
             elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
@@ -189,7 +196,7 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__rmul__(self)
         else:
-            raise NotImplementedError("Product of Unit and " + type(other) + " not implemented.")
+            raise NotImplementedError("Product of " + str(type(self)) + " and " + str(type(other)) + " not implemented.")
 
     def __rmul__(self, other):
         return self.__mul__(other)
@@ -197,7 +204,7 @@ class Unit(object):
     def __pow__(self, other):
         from .units.unitless import Dimensionless, Percentage
         from .units.define import units
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value ** other.value, other.unit)
             elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
@@ -232,7 +239,7 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__rpow__(self)
         else:
-            raise NotImplementedError("Power of Unit to " + type(other) + " not implemented.")
+            raise NotImplementedError("Power of " + str(type(self)) + " to " + str(type(other)) + " not implemented.")
 
     def __rpow__(self, other):
         from .units.unitless import Dimensionless, Percentage
@@ -247,7 +254,7 @@ class Unit(object):
     def __sub__(self, other):
         # return self.__add__(other * -1)
         from .units.unitless import Dimensionless, Percentage
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if other.kind is self.kind:
                 if self.unit == other.unit:
                     return self.kind(self.value - other.value, self.unit)
@@ -281,7 +288,7 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__rsub__(self)
         else:
-            raise NotImplementedError("Subtraction of Unit and " + type(other) + " not implemented.")
+            raise NotImplementedError("Subtraction of " + str(type(self)) + " and " + str(type(other)) + " not implemented.")
 
     def __rsub__(self, other):
         return self.__neg__() + other
@@ -289,7 +296,7 @@ class Unit(object):
     def __truediv__(self, other):
         from .units.unitless import Dimensionless, Percentage
         from .units.define import units
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value / other.value, '1/' + other.unit)
             elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
@@ -318,7 +325,7 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__rtruediv__(self)
         else:
-            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
+            raise NotImplementedError("Division of " + str(type(self)) + " by " + str(type(other)) + " not implemented.")
 
     def __rtruediv__(self, other):
         from .units.define import units
@@ -330,12 +337,12 @@ class Unit(object):
         elif type(other) in numeric:
             return units(other / self.value, self.unit + '-1')
         else:
-            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
+            raise NotImplementedError("Division of " + str(type(self)) + " by " + str(type(other)) + " not implemented.")
 
     def __floordiv__(self, other):
         from .units.unitless import Dimensionless, Percentage
         from .units.define import units
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value // other.value, '1/' + other.unit)
             elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
@@ -364,7 +371,7 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__rfloordiv__(self)
         else:
-            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
+            raise NotImplementedError("Division of " + str(type(self)) + " by " + str(type(other)) + " not implemented.")
 
     def __rfloordiv__(self, other):
         from .units.define import units
@@ -376,12 +383,12 @@ class Unit(object):
         elif type(other) in numeric:
             return units(other // self.value, self.unit + '-1')
         else:
-            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
+            raise NotImplementedError("Division of " + str(type(self)) + " by " + str(type(other)) + " not implemented.")
 
     def __matmul__(self, other):
         from .units.unitless import Dimensionless, Percentage
         from .units.define import units
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value / other.value, '1/' + other.unit)
             elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
@@ -402,12 +409,12 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__rmatmul__(self)
         else:
-            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
+            raise NotImplementedError("Division of " + str(type(self)) + " by " + str(type(other)) + " not implemented.")
 
     def __mod__(self, other):
         from .units.unitless import Dimensionless, Percentage
         from .units.define import units
-        if '.units.' in str(type(other)):
+        if isinstance(other, Unit):
             if self.kind in (Dimensionless, Percentage) and other.kind not in (Dimensionless, Percentage):
                 return other.kind(self.value % other.value, self.unit)
             elif self.kind is Percentage and other.kind in (Dimensionless, Percentage):
@@ -435,7 +442,7 @@ class Unit(object):
         elif hasattr(other, 'type') and other.type in ('SimSeries', 'SimDataFrame'):
             return other.__rmod__(self)
         else:
-            raise NotImplementedError("Module of Unit when divided by " + type(other) + " not implemented.")
+            raise NotImplementedError("Module of " + str(type(self)) + " when divided by " + str(type(other)) + " not implemented.")
 
     def __lt__(self, other) -> bool:
         if type(self) == type(other):
@@ -579,12 +586,15 @@ class Unit(object):
             raise WrongValueError(str(value))
 
     def check_unit(self, units):
-        if type(units) is not str:
-            try:
-                units = units.unit
-            except AttributeError:
-                raise WrongUnitsError("'" + str(units) + "' for '" + str(self.name) + "'")
-        if units in self.kind.classUnits:
+        if type(units) is str:
+            pass
+        elif type(units) is not str and hasattr(units, 'units'):
+            units = units.unit
+        else:
+            raise WrongUnitsError("'" + str(units) + "' for '" + str(self.name) + "'")
+        if units != 'ounce' and units in self.kind.classUnits:
+            return units
+        elif units == 'ounce':
             return units
         else:
             raise WrongUnitsError("'" + str(units) + "' for '" + str(self.name) + "'")
