@@ -6,17 +6,27 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.2'
-__release__ = 20230107
-__all__ = ['Pressure', 'Weight', 'Compressibility']
+__version__ = '0.5.4'
+__release__ = 20230121
+__all__ = ['Force', 'Pressure', 'Weight', 'Compressibility', 'Viscosity']
 
-from unyts.dictionaries import dictionary
-from unyts.unit_class import Unit
-from unyts.helpers.common_classes import unit_or_str, numeric
+from ..dictionaries import dictionary as _dictionary
+from ..unit_class import Unit
+from ..helpers.common_classes import unit_or_str, numeric
+
+
+class Force(Unit):
+    classUnits = _dictionary['Force']
+
+    def __init__(self, value: numeric, units: unit_or_str):
+        self.name = 'force'
+        self.kind = Force
+        self.value = self.check_value(value)
+        self.unit = self.check_unit(units)
 
 
 class Pressure(Unit):
-    classUnits = dictionary['Pressure']
+    classUnits = _dictionary['Pressure']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'pressure'
@@ -26,7 +36,7 @@ class Pressure(Unit):
 
 
 class Weight(Unit):
-    classUnits = dictionary['Weight']
+    classUnits = _dictionary['Weight']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'weight'
@@ -36,10 +46,20 @@ class Weight(Unit):
 
 
 class Compressibility(Unit):
-    classUnits = dictionary['Compressibility']
+    classUnits = _dictionary['Compressibility']
 
     def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'compressibility'
         self.kind = Compressibility
         self.value = self.check_value(value)
         self.unit = self.check_unit(units)
+
+class Viscosity(Unit):
+    classUnits = _dictionary['Viscosity']
+
+    def __init__(self, value: numeric, units: unit_or_str):
+        self.name = 'viscosity'
+        self.kind = Viscosity
+        self.value = self.check_value(value)
+        self.unit = self.check_unit(units)
+
